@@ -1,6 +1,8 @@
-from .core import CatboostError
+from .core import CatboostError, get_catboost_bin_module, ARRAY_TYPES
 from collections import defaultdict
 
+_eval_metric_util = get_catboost_bin_module()._eval_metric_util
+
 
 def create_cd(
     label=None,
@@ -48,3 +50,11 @@ def create_cd(
     with open(output_path, 'w') as f:
         for index, (title, name) in sorted(_column_description.items()):
             f.write('{}\t{}\t{}\n'.format(index, title, name))
+
+
+def eval_metric(label, approx, metric, weight=None, group_id=None, thread_count=-1):
+    if len(approx) == 0:
+        approx = [[]]
+    if not isinstance(approx[0], ARRAY_TYPES):
+        approx = [approx]
+    return _eval_metric_util(label, approx, metric, weight, group_id, thread_count)
